"""
Shared constants for Promptheus configuration and provider behaviour.
"""

VERSION = "0.1.0"
GITHUB_REPO = "https://github.com/abhichandra21/Promptheus"
GITHUB_ISSUES = f"{GITHUB_REPO}/issues"

DEFAULT_PROVIDER_TIMEOUT = 60  # seconds
DEFAULT_CLARIFICATION_MAX_TOKENS = 2000
DEFAULT_REFINEMENT_MAX_TOKENS = 4000
DEFAULT_TWEAK_MAX_TOKENS = 2000

PROMPTHEUS_DEBUG_ENV = "PROMPTHEUS_DEBUG"
